@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,27 +7,25 @@
 #include "gravatarconfigwidgettest.h"
 #include "../src/widgets/gravatarconfigwidget.h"
 #include <QCheckBox>
-#include <QTest>
 #include <QPushButton>
-#include <qtestmouse.h>
 #include <QSignalSpy>
+#include <QTest>
+#include <qtestmouse.h>
 
 GravatarConfigWidgetTest::GravatarConfigWidgetTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-GravatarConfigWidgetTest::~GravatarConfigWidgetTest()
-{
-}
+GravatarConfigWidgetTest::~GravatarConfigWidgetTest() = default;
 
 void GravatarConfigWidgetTest::shouldHaveDefaultValue()
 {
     Gravatar::GravatarConfigWidget w;
-    auto *enableGravatar = w.findChild<QCheckBox *>(QStringLiteral("gravatarcheckbox"));
+    auto enableGravatar = w.findChild<QCheckBox *>(QStringLiteral("gravatarcheckbox"));
     QVERIFY(enableGravatar);
 
-    auto *configure = w.findChild<QPushButton *>(QStringLiteral("configure"));
+    auto configure = w.findChild<QPushButton *>(QStringLiteral("configure"));
     QVERIFY(configure);
 }
 
@@ -35,9 +33,9 @@ void GravatarConfigWidgetTest::shouldChangeState()
 {
     Gravatar::GravatarConfigWidget w;
     w.show();
-    auto *enableGravatar = w.findChild<QCheckBox *>(QStringLiteral("gravatarcheckbox"));
+    auto enableGravatar = w.findChild<QCheckBox *>(QStringLiteral("gravatarcheckbox"));
 
-    auto *configure = w.findChild<QPushButton *>(QStringLiteral("configure"));
+    auto configure = w.findChild<QPushButton *>(QStringLiteral("configure"));
     QVERIFY(!configure->isEnabled());
     enableGravatar->toggle();
     QVERIFY(configure->isEnabled());
@@ -47,7 +45,7 @@ void GravatarConfigWidgetTest::shoulEmitConfigChangedSignal()
 {
     Gravatar::GravatarConfigWidget w;
     w.show();
-    auto *enableGravatar = w.findChild<QCheckBox *>(QStringLiteral("gravatarcheckbox"));
+    auto enableGravatar = w.findChild<QCheckBox *>(QStringLiteral("gravatarcheckbox"));
 
     QSignalSpy spy(&w, &Gravatar::GravatarConfigWidget::configChanged);
     QTest::mouseClick(enableGravatar, Qt::LeftButton);
